/* $Id: wl.h,v 1.7 2006/05/04 18:44:47 hacki Exp $ */

/*
 * Copyright (c) 2005, 2006 Marcus Glocker <marcus@nazgul.ch>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef __OpenBSD__ 
#define IFM_TYPE_MATCH(dt, t) (IFM_TYPE((dt)) == 0 || \
    IFM_TYPE((dt)) == IFM_TYPE((t)))
#endif

/*
 * prototypes
 */
int	get_wep(const char *);
int	get_channel(const char *);
int	get_signal(const char *, const char *);
int 	get_wi_signal(const char *);
int	check_nic(const char *);
char *	get_speed(const char *);
char *	get_status(const char *);
char *	get_nwid(const char *);
char *	get_first_wnic(void);
char *	translate_speed(const char *);
